@@ -20,6 +20,7 @@
 
 #include "kpopup.h"
 #include "make_popup.h"
+#include "message.h"
 #include "misc.h"
 
 #include <stdio.h>
@@ -44,7 +45,7 @@ KPopup::KPopup(QWidget *, const char *name) : KMainWindow (0L, name) {
     QWidget *mainWidget = new QWidget(this, "mainWidget");
     setCentralWidget(mainWidget);
     QGridLayout *layout = new QGridLayout(mainWidget);
-       
+
     initToolbar();
     initStatusbar();
 
@@ -66,19 +67,20 @@ KPopup::KPopup(QWidget *, const char *name) : KMainWindow (0L, name) {
     lbl_SenderValue -> setAlignment(Qt::AlignLeft);
     lbl_SenderValue -> setMinimumWidth(250);
     layout -> addWidget(lbl_SenderValue, 1, 2);
-    
+
     QLabel *lbl_DateTime = new QLabel(i18n("Popup time:"), mainWidget);
     lbl_DateTime -> setMinimumWidth(100);
     lbl_DateTime -> setAlignment(Qt::AlignLeft);
     layout -> addWidget(lbl_DateTime, 3, 1);
-    
+
     lbl_DateTimeValue = new QLabel("", mainWidget);
     lbl_DateTimeValue -> setFrameStyle(QFrame::Panel | QFrame::Sunken);
     lbl_DateTimeValue -> setAlignment(Qt::AlignLeft);
     lbl_DateTimeValue -> setMinimumWidth(250);
     layout -> addWidget(lbl_DateTimeValue, 3, 2);
-    
-    tv_Text = new QTextView(mainWidget);
+
+    tv_Text = new QTextEdit(mainWidget);
+    tv_Text -> setReadOnly(TRUE);
     layout -> addMultiCellWidget(tv_Text, 5, 5, 1, 2);
 
     layout -> addColSpacing(0, 10);
@@ -151,7 +153,7 @@ void KPopup::initToolbar() {
     toolbar -> insertSeparator();
     toolbar -> insertSeparator();
     toolbar -> insertButton("help", ID_HELP, true, i18n("Help"));
-    
+
     connect(toolbar, SIGNAL(clicked(int)), SLOT(commandCallback(int)));
 }
 
@@ -209,7 +211,7 @@ void KPopup::statusBarTimerDone() {
     number.setNum(actual, 10);
     statusText.append(number);
     statusText.append("/");
-    number.setNum(senderMap.count(), 10);
+    number.setNum(messageMap.count(), 10);
     statusText.append(number);
 
     setStatusText(statusText);
@@ -219,9 +221,9 @@ void KPopup::statusBarTimerDone() {
     number.setNum(actual, 10);
     trayText.append(number);
     trayText.append("/");
-    number.setNum(senderMap.count(), 10);
+    number.setNum(messageMap.count(), 10);
     trayText.append(number);
-    
+
     QToolTip::remove(tray);
     QToolTip::add(tray, trayText);
 }
@@ -248,9 +250,9 @@ void KPopup::popupFileTimerDone() {
             ++it;
             if (fileInfo -> isFile()) {
                 QString fileName(fileInfo -> fileName());
-                
-                kdDebug() << "file " << fileName.latin1() << endl;
-                
+
+                kdDebug() << "file " << fileName.local8Bit() << endl;
+
                 // read popup file
                 QString popupFilePath(KPOPUPPATH);
                 popupFilePath.append("/");
@@ -268,8 +270,8 @@ void KPopup::popupFileTimerDone() {
                         i++;
                         line = stream.readLine();
 
-                        kdDebug() << i << " " << line.latin1() << endl;
-                        
+                        kdDebug() << i << " " << line.local8Bit() << endl;
+
                         if (i == 1)  {
                             time.append(line);
                             continue;
@@ -339,15 +341,23 @@ void KPopup::answerPopup() {
 /*
  * method signalNewMessage
  */
-void KPopup::signalNewMessage(QString sender, QString message, QString time) {
+void KPopup::signalNewMessage(QString sender, QString text, QString receivedTime) {
 
     kdDebug() << "popup received" << endl;
 
-    actual = senderMap.count() + 1;
-    senderMap.insert(actual, sender);
-    popupTextMap.insert(actual, message);
-    timeMap.insert(actual, time);
+    // increase counter
+    actual = messageMap.count() + 1;
 
+    // create and fill message
+    Message message;
+    message.setSender(sender);
+    message.setText(text);
+    message.setReceivedTime(receivedTime);
+
+    // put message to map
+    messageMap.insert(actual, message);
+
+    // show popup
     showPopup();
     kapp -> beep();
     showNormal();
@@ -358,7 +368,7 @@ void KPopup::signalNewMessage(QString sender, QString message, QString time) {
  * method checked maps and set buttons in toolbar
  */
 void KPopup::checkMap() {
-    int count = senderMap.count();
+    int count = messageMap.count();
 
     if (count != 0) {
         toolBar() -> getButton(ID_DELETE_POPUP) -> setEnabled(true);
@@ -395,10 +405,14 @@ void KPopup::checkMap() {
  */
 void KPopup::showPopup() {
 
-    if (!senderMap.isEmpty()) {
-        lbl_SenderValue -> setText(senderMap[actual]);
-        lbl_DateTimeValue -> setText(timeMap[actual]);
-        tv_Text -> setText(popupTextMap[actual]);
+    // if message empty then show empty values
+
+    if (! messageMap.isEmpty()) {
+        Message message = messageMap[actual];
+
+        lbl_SenderValue -> setText(message.getSender());
+        lbl_DateTimeValue -> setText(message.getReceivedTime());
+        tv_Text -> setText(message.getText());
     } else {
         lbl_SenderValue -> setText("");
         lbl_DateTimeValue -> setText("");
@@ -414,21 +428,15 @@ void KPopup::showPopup() {
  * method remove a popup from maps
  */
 void KPopup::deletePopup() {
-    int count = senderMap.count();
+    int count = messageMap.count();
 
     if (actual == count) {
-        senderMap.remove(actual);
-        timeMap.remove(actual);
-        popupTextMap.remove(actual);
+        messageMap.remove(actual);
         actual--;
     } else {
         for (int i = actual; i <= count - 1; i++) {
-            senderMap.insert(i, senderMap[i + 1]);
-            senderMap.remove(i + 1);
-            timeMap.insert(i, timeMap[i + 1]);
-            timeMap.remove(i + 1);
-            popupTextMap.insert(i, popupTextMap[i + 1]);
-            popupTextMap.remove(i + 1);
+            messageMap.insert(i, messageMap[i + 1]);
+            messageMap.remove(i + 1);
         }
     }
 
