@@ -34,9 +34,11 @@
 
 #include <qlabel.h>
 #include <qmap.h>
-#include <qtextview.h>
+#include <qtextedit.h>
 #include <qtimer.h>
 
+#include "message.h"
+
 class KPopup : public KMainWindow {
     Q_OBJECT
 
@@ -77,10 +79,8 @@ class KPopup : public KMainWindow {
             KSystemTray *tray;
             QLabel *lbl_SenderValue;
             QLabel *lbl_DateTimeValue;
-            QMap<int, QString> senderMap;
-            QMap<int, QString> popupTextMap;
-            QMap<int, QString> timeMap;
-            QTextView *tv_Text;
+            QMap<int, Message> messageMap;
+            QTextEdit *tv_Text;
             QTimer *statusBarTimer;
             QTimer *popupFileTimer;
             int actual;
