@@ -45,7 +45,7 @@ Make_Popup::Make_Popup(QWidget *parent, const char *name, QString sender) : KDia
     lbl_Group -> setMinimumWidth(50);
     layout -> addWidget(lbl_Group, 1, 1);
 
-    cb_Group = new KComboBox(true, this);
+    KComboBox *cb_Group = new KComboBox(true, this);
     cb_Group -> setMinimumWidth(250);
     layout -> addWidget(cb_Group, 1, 3);
     cb_Group -> setEditable(false);
@@ -91,13 +91,31 @@ Make_Popup::Make_Popup(QWidget *parent, const char *name, QString sender) : KDia
     new KAction("send", CTRL+Key_S, this, SLOT(sendPopup()), actColl, "send");
     new KAction("cancel", CTRL+Key_C, this, SLOT(reject()), actColl, "cancel");
 
+    // fill group combo/host combobox
     if (sender.isEmpty()) {
-        cb_Group -> insertItem("NO GROUP", -1);
-        readGroupList();
+        QStringList groupList = readGroupList();
+
+        // check groups available
+        if (groupList.count() == 0) {
+            cb_Group -> insertItem(i18n("No group found"), -1);
+            cb_Group -> setEnabled(false);
+        } else {
+            for (QStringList::Iterator it = groupList.begin(); it != groupList.end(); it++ ) {
+                cb_Group -> insertItem(*it, -1);
+            }
+
+            // get host for first entry if only one group available
+            if (groupList.count() == 1) {
+                changeGroupBox(cb_Group -> currentText());
+            }
+            else {
+                cb_Group -> insertItem("", 0);
+            }
+        }
     } else {
         cb_Group -> setEnabled(false);
         cb_Host -> insertItem(sender);
-        cb_Host -> setEnabled(false);
+        cb_Host -> setEnabled(true);
     }
 }
 
@@ -122,17 +140,17 @@ void Make_Popup::sendPopup() {
     cmd.append(cb_Host -> currentText());
     cmd.append("' -N -U '");
     cmd.append(getHostName());
-    cmd.append("' > /dev/null");
+    cmd.append("'");
 
-    kdDebug() << cmd.latin1() << endl;
+    kdDebug() << cmd.local8Bit() << endl;
 
     // open process
-    FILE *sendprocess = popen(cmd.latin1(), "w");
+    FILE *sendprocess = popen(cmd.local8Bit(), "w");
 
     // write data
     if (sendprocess != NULL) {
         while (linecount < mle_Text -> numLines()) {
-            fprintf(sendprocess, "%s\n", (const char *)mle_Text -> textLine(linecount));
+            fprintf(sendprocess, "%s\n", (const char *)mle_Text -> textLine(linecount).utf8());
             linecount++;
         }
         if (pclose(sendprocess) == 0) {
@@ -166,7 +184,9 @@ QString Make_Popup::getHostName() {
 /*
  * read available groups from samba (localhost)
  */
-void Make_Popup::readGroupList() {
+QStringList Make_Popup::readGroupList() {
+
+    QStringList groupList;
 
     QString cmd;
     cmd.append(SMBPATH);
@@ -175,7 +195,7 @@ void Make_Popup::readGroupList() {
     cmd.append(" -N");
 
     // open process
-    FILE *sambaQuery = popen(cmd.latin1(), "r");
+    FILE *sambaQuery = popen(cmd.local8Bit(), "r");
 
     // read data
     if (sambaQuery != NULL) {
@@ -196,7 +216,9 @@ void Make_Popup::readGroupList() {
                 line.remove(0, 1);
                 QString group = line.mid(0, line.find("  ", 0, true));
                 kdDebug() << "found group = '" << group << "'" << endl;
-                cb_Group -> insertItem(group, -1);
+
+                // add group to list
+                groupList.append(group);
             }
         }
     }
@@ -216,19 +238,18 @@ void Make_Popup::readGroupList() {
             perror(errorMsg);
         }
     }
+
+    // sort list
+    groupList.sort();
+
+    return groupList;
 }
 
 
 /*
  * read available host from group with samba
  */
-void Make_Popup::readHostList(QString group) {
-
-    cb_Host -> clear();
-    cb_Host -> insertItem("NO HOST", -1);
-    if (group == "NO GROUP") {
-        return;
-    }
+QStringList Make_Popup::readHostList(QString group) {
 
     QString host;
     QString cmd;
@@ -240,7 +261,7 @@ void Make_Popup::readHostList(QString group) {
     cmd.append(" -N");
 
     // open process
-    FILE *sambaQuery = popen(cmd.latin1(), "r");
+    FILE *sambaQuery = popen(cmd.local8Bit(), "r");
 
     // read data
     if (sambaQuery != NULL) {
@@ -287,9 +308,11 @@ void Make_Popup::readHostList(QString group) {
         }
     }
 
+    QStringList hostList;
+
     // no master fround for group
     if (host.isEmpty()) {
-        return;
+        return hostList;
     }
 
     // search hosts is group
@@ -300,7 +323,7 @@ void Make_Popup::readHostList(QString group) {
     cmd.append("' -N");
 
     // open process
-    sambaQuery = popen(cmd.latin1(), "r");
+    sambaQuery = popen(cmd.local8Bit(), "r");
 
     // read data
     if (sambaQuery != NULL) {
@@ -322,7 +345,9 @@ void Make_Popup::readHostList(QString group) {
                 host = line.mid(0, line.find("  ", 0, true));
                 if (! host.isEmpty()) {
                     kdDebug() << "found host= '" << host << "' in group = '" << group << "'" << endl;
-                    cb_Host -> insertItem(host, -1);
+
+                    // add host to list
+                    hostList.append(host);
                 }
             }
         }
@@ -343,6 +368,11 @@ void Make_Popup::readHostList(QString group) {
             perror(errorMsg);
         }
     }
+
+    // sort list
+    hostList.sort();
+
+    return hostList;
 }
 
 
@@ -351,5 +381,20 @@ void Make_Popup::readHostList(QString group) {
  */
 void Make_Popup::changeGroupBox(const QString &group) {
 
-    readHostList(group);
+    // remove older values
+    cb_Host -> clear();
+
+    // get hosts from group
+    QStringList hostList = readHostList(group);
+
+    // check host available
+    if (hostList.count() == 0) {
+        cb_Host -> insertItem(i18n("No host found"), -1);
+    } else {
+        cb_Host -> insertItem("", -1);
+
+        for (QStringList::Iterator it = hostList.begin(); it != hostList.end(); it++ ) {
+            cb_Host -> insertItem(*it, -1);
+        }
+    }
 }
